********************************************************************************
********************************************************************************
***** Replication Do-File
***** Left Parties, Voter Preferences, and Economic Policy-Making in Europe
***** Fabian Engler and Reimut Zohlnhöfer
***** Paper accepted by Journal of European Public Policy
***** November 2018
********************************************************************************
********************************************************************************


***** Table of contents

***** 1. Micro-level analysis (Role of Government IV 2006 data)
***** 2. Micro-level analysis (European Values Study 2008 data)
***** 3. Party-level analysis
***** 4. Macro-level analysis
***** 5. Endogeneity tests



********************************************************************************
********************************************************************************
********************************************************************************
***** 1. Micro-level analysis (Role of Government IV 2006 data)
********************************************************************************
********************************************************************************
********************************************************************************

*use "C:\Users\Engler\Papers\LeftPartiesVoterPreferencesEconomicPolicy\Mikroanalyse\replication_Engler_Zohlnhoefer_2018_micro-level_1_final.dta", clear


********************************************************************************
***** 1.1 Variable description
********************************************************************************

* subsjobprotec       -> support declining industries to protect jobs (1 strongly in favour of) (2 in favour of) (3 neither in favour of nor against) (4 against) (5 strongly against)
* regulationcuts      -> less government regulation of business (1 stronly against) (2 against) (3 neither in favour of nor against) (4 in favour of) (5 strongly in favour of)
* spendingcuts        -> cuts in government spending (1 stronly against) (2 against) (3 neither in favour of nor against) (4 in favour of) (5 strongly in favour of)
* servcl              -> member of routine service class (1 yes) (0 no)
* middcl              -> member of middle-class (1 yes) (0 no)
* emplcl              -> member of employer class (1 yes) (0 no)
* female              -> woman (1 yes) (0 no)
* age                 -> age in years
* educyrs             -> years of education (those still in education dropped)
* union2              -> currently union member (1 yes) (0 no)
* middcl_soccul       -> member of new part of the middle-class (i.e. sociocultural (semi-)professionals) (1 yes) ( 0 no)
* middcl_minus_soccul -> member of the not new part of the middle-class (1 yes) (0 no)
* leftright           -> (1 far left etc) (2 left, center left) (3 center, liberal) (4 right, conservative) (5 far right etc)
* subsjobprotec_dich  -> subsjobprotec dichotomized (1 "strongly against" & "against") (0 "neither in favour of nor against" & "against" & "strongly against")
* regulationcuts_dich -> regulationcuts dichotomized (1 "strongly in favour of" & "in favour of") (0 "neither in favour if nor against" & "in favour of" & "strongly in favour of")
* spendingcuts_dich   -> spendingcuts dichotomized (1 "strongly in favour of" & "in favour of") (0 "neither in favour if nor against" & "in favour of" & "strongly in favour of")
* europ_sample        -> reduced sample, i.e. only countries that are covered in the party- and the macro-level analyses (1 yes) (0 no)
* ccode               -> country code


********************************************************************************
***** 1.2 Table 1 (Models 1-3) / Table A4
********************************************************************************

ologit subsjobprotec servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

ologit regulationcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

ologit spendingcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.3 Table A5 (Models 1-3)
********************************************************************************

gologit2 subsjobprotec servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

gologit2 regulationcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

gologit2 spendingcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.4 Table A6 (Models 1-3)
********************************************************************************

ologit subsjobprotec servcl middcl_soccul middcl_minus_soccul emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

ologit regulationcuts servcl middcl_soccul middcl_minus_soccul emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

ologit spendingcuts servcl middcl_soccul middcl_minus_soccul emplcl female age educyrs union2 i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.5 Table A7 (Models 1-3)
********************************************************************************

ologit subsjobprotec servcl middcl emplcl female age educyrs union2 leftright i.ccode, cluster (ccode) robust

ologit regulationcuts servcl middcl emplcl female age educyrs union2 leftright i.ccode, cluster (ccode) robust

ologit spendingcuts servcl middcl emplcl female age educyrs union2 leftright i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.6 Table A8 (Models 1-3)
********************************************************************************

logit subsjobprotec_dich servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

logit regulationcuts_dich servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

logit spendingcuts_dich servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.7 Table A9 (Models 1-3)
********************************************************************************

regress subsjobprotec servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

regress regulationcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust

regress spendingcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust


********************************************************************************
***** 1.8 Table A10 (Models 1-3)
********************************************************************************

ologit subsjobprotec servcl middcl emplcl female age educyrs union2 i.ccode if europ_sample==1, cluster (ccode) robust

ologit regulationcuts servcl middcl emplcl female age educyrs union2 i.ccode if europ_sample==1, cluster (ccode) robust

ologit spendingcuts servcl middcl emplcl female age educyrs union2 i.ccode if europ_sample==1, cluster (ccode) robust


********************************************************************************
***** 1.9 Data for Figure A2 (1/2)
********************************************************************************

********************************************************************************
***** Predicted Probabilities for "subsidies for job protection"
********************************************************************************
ologit subsjobprotec servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust
gen sample_subs=e(sample)
sum female if sample_subs==1, detail // median=0
sum age if sample_subs==1, detail // median=43
sum educyrs if sample_subs==1, detail // meian=13
sum union2 if sample_subs==1, detail // median=0
tab ccode if sample_subs==1 // median(among European countries covered by RoG IV and EVS)=13
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(1)) atmeans 
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(2)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(3)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(4)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(5)) atmeans


********************************************************************************
***** Predicted Probabilities for "less regulation"
********************************************************************************
ologit regulationcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust
gen sample_regu=e(sample)
sum female if sample_regu==1, detail // median=0
sum age if sample_regu==1, detail // median=43
sum educyrs if sample_regu==1, detail // median=13
sum union2 if sample_regu==1, detail // median=0
tab ccode if sample_regu==1 // median(among European countries covered by RoG IV and EVS)=13
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(1)) atmeans 
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(2)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(3)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(4)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(5)) atmeans


********************************************************************************
***** Predicted Probabilities for "spending cuts"
********************************************************************************
ologit spendingcuts servcl middcl emplcl female age educyrs union2 i.ccode, cluster (ccode) robust
gen sample_spend=e(sample)
sum female if sample_spend==1, detail // median=0
sum age if sample_spend==1, detail // median=43
sum educyrs if sample_spend==1, detail // median=13
sum union2 if sample_spend==1, detail // median=0
tab ccode if sample_spend==1 // median(among European countries covered by RoG IV and EVS)=13
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(1)) atmeans 
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(2)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(3)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(4)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=43 educyrs=13 union2=0 ccode=13) predict(outcome(5)) atmeans




********************************************************************************
********************************************************************************
********************************************************************************
***** 2. Micro-level analysis (European Values Study 2008 data)
********************************************************************************
********************************************************************************
********************************************************************************

*use "C:\Users\Engler\Papers\LeftPartiesVoterPreferencesEconomicPolicy\Mikroanalyse\replication_Engler_Zohlnhoefer_2018_micro-level_2_final.dta", clear


********************************************************************************
***** 2.1 Variable description
********************************************************************************

* moreprivown         -> private vs. government ownership (1 government ownership increased) (2) (3) (4) (5) (6) (7) (8) (9) (10 private ownership increased)
* servcl              -> member of routine service class (1 yes) (0 no)
* middcl              -> member of middle-class (1 yes) (0 no)
* emplcl              -> member of employer class (1 yes) (0 no)
* female              -> woman (1 yes) (0 no)
* age                 -> age in years
* education           -> age completed education
* union               -> currently union member (1 yes) (0 no)
* middcl_soccul       -> member of new part of the middle-class (i.e. sociocultural (semi-)professionals) (1 yes) ( 0 no)
* middcl_minus_soccul -> member of the not new part of the middle-class (1 yes) (0 no)
* leftright           -> left-right self-placement(1 left) (2) (3) (4) (5) (6) (7) (8) (9) (10 right)
* moreprivown_dich    -> private vs. government ownership dichotomized (1 (6) (7) (8) (9) (10 private ownership increased)) (0 (1 government ownership increased) (2) (3) (4) (5))
* ccode               -> country code


********************************************************************************
***** 2.2 Table 1 (Model 4) / Table A4
********************************************************************************

ologit moreprivown servcl middcl emplcl female age education union i.country, cluster(country) robust


********************************************************************************
***** 2.3 Table A5 (Model 4)
********************************************************************************

gologit2 moreprivown servcl middcl emplcl female age education union i.country, cluster(country) robust


********************************************************************************
***** 2.4 Table A6 (Model 4)
********************************************************************************

ologit moreprivown servcl middcl_soccul middcl_minus_soccul emplcl female age education union i.country, cluster(country) robust


********************************************************************************
***** 2.5 Table A7 (Model 4)
********************************************************************************

ologit moreprivown servcl middcl emplcl female age education union leftright i.country, cluster(country) robust


********************************************************************************
***** 2.6 Table A8 (Model 4)
********************************************************************************

logit moreprivown_dich servcl middcl emplcl female age education union i.country, cluster(country) robust


********************************************************************************
***** 2.7 Table A9 (Model 4)
********************************************************************************

regress moreprivown servcl middcl emplcl female age education union i.country, cluster(country) robust


********************************************************************************
***** 2.8 Data for Figure A2 (2/2)
********************************************************************************

********************************************************************************
***** Predicted Probabilities for "increase of private ownership"
********************************************************************************
ologit moreprivown servcl middcl emplcl female age education union i.country, cluster (country) robust
gen sample_priv=e(sample)
sum female if sample_priv==1, detail // median=0
sum age if sample_priv==1, detail // median=42
sum education if sample_priv==1, detail // median=19
sum union if sample_priv==1, detail // median=0
tab country if sample_priv==1, nolabel // median(among European countries covered by RoG IV and EVS)=208
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(1)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(2)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(3)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(4)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(5)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(6)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(7)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(8)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(9)) atmeans
margins, at(servcl=0 middcl=(0/1) emplcl=0 female=0 age=42 education=19 union=0 country=208) predict(outcome(10)) atmeans




********************************************************************************
********************************************************************************
********************************************************************************
***** 3. Party-level analysis
********************************************************************************
********************************************************************************
********************************************************************************

*use "C:\Users\Engler\Papers\LeftPartiesVoterPreferencesEconomicPolicy\PartPosAnalyse\replication_Engler_Zohlnhoefer_2018_party-level_final.dta", clear

xtset party_id election_number

********************************************************************************
***** 3.1 Variable description
********************************************************************************

* per402_100             -> Comparative Manifesto Project (Volkens et al. 2017) item "per402: incentives: positive", original data (proportion instead of absolute percentages)
* per403_100             -> Comparative Manifesto Project (Volkens et al. 2017) item "per403: market regulation", original data (proportion instead of absolute percentages)
* per413_100             -> Comparative Manifesto Project (Volkens et al. 2017) item "per413: nationalisation", original data (proportion instead of absolute percentages)
* log_per402_100_1       -> Comparative Manifesto Project (Volkens et al. 2017) item "per402: incentives: positive", adjusted and logarithmized data [log(per402_100+1)]
* log_per403_100_1       -> Comparative Manifesto Project (Volkens et al. 2017) item "per403: market regulation", adjusted and logarithmized data [log(per403_100+1)]
* log_per413_100_1       -> Comparative Manifesto Project (Volkens et al. 2017) item "per413: nationalisation", adjusted and logarithmized data [log(per413_100+1)]
* log_per401_100_1       -> Comparative Manifesto Project (Volkens et al. 2017) item "per401: free market economy", adjusted and logarithmized data [log(per401_100+1)]
* l_log_per402_100_1     -> Comparative Manifesto Project (Volkens et al. 2017) item "per402: incentives: positive", adjusted and logarithmized data  (1 election lag)
* l_log_per403_100_1     -> Comparative Manifesto Project (Volkens et al. 2017) item "per403: market regulation", adjusted and logarithmized data  (1 election lag)
* l_log_per413_100_1     -> Comparative Manifesto Project (Volkens et al. 2017) item "per413: nationalisation", adjusted and logarithmized data  (1 elction lag)
* l_middcl_left2vote_ma2 -> share of middle-class voters among all employed left party voters (moving average (t), (t-1) (t-2))  (1 year lag)
* l_workcl_left2vote_ma2 -> share of working-class voters among all employed left party voters (moving average (t), (t-1) (t-2))  (1 year lag)
* l_middcl_left1vote_ma2 -> share of middle-class voters among all employed old left party voters (i.e. socialists/communists and social-democrats but not Greens) (moving average (t), (t-1) (t-2))  (1 year lag)
* l_workcl_left1vote_ma2 -> share of working-class voters among all employed olde left party voters (i.e. socialists/communists and social-democrats but not Greens) (moving average (t), (t-1) (t-2))  (1 year lag)
* l_actualflows          -> actual flows sub-index of Dreher's (2006) KOF index of globalization (1 year lag)
* l_unemp                -> unemployment rate  (1 year lag)
* l_realgdpgr            -> GDP growth  (1 year lag)
* l_debt                 -> public debt in percentage of GDP  (1 year lag)
* l_subsidies            -> subsidy spending in percentage of GDP  (1 year lag)
* l_ectr                 -> OECD ETCR index of product market regulation  (1 year lag)
* l_privatis             -> index of state ownership  (1 year lag)
* l_ud                   -> union density  (1 year lag)
* dummy_80               -> Dummy for election year in 1980s (1 yes) (0 no)
* dummy_90               -> Dummy for election year in 1990s (1 yes) (0 no)
* ccode					 ->	country code
* party_id               -> party code
* greenparty             -> Dummy for identifying green parties (1 yes) (0 no)

***Note that if there were two elections in a country in one year and CMP coded a party's manifestos of each election, we took the average of an item's values of both manifestos.

********************************************************************************
***** 3.2 Table 2 / Table A11
********************************************************************************

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)


********************************************************************************
***** 3.3 Table A12
********************************************************************************

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left1vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left1vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left1vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left1vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left1vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left1vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode if greenparty==0, cluster(ccode)


********************************************************************************
***** 3.4 Table A13
********************************************************************************

reg per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)


********************************************************************************
***** 3.5 Table A14
********************************************************************************

fracreg logit per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)

fracreg logit per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)

fracreg logit per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)

fracreg logit per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)

fracreg logit per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)

fracreg logit per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, vce(cluster ccode)


********************************************************************************
***** 3.6 Table A15
********************************************************************************

zoib per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)

zoib per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)

zoib per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)

zoib per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)

zoib per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)

zoib per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, zeroinfl(l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode) cluster(ccode)


********************************************************************************
***** 3.7 Table A16
********************************************************************************

reg log_per402_100_1 l_log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per402_100_1 l_log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)


********************************************************************************
***** 3.8 Table A17
********************************************************************************

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_ectr l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_privatis l_ud dummy_80 dummy_90 i.party_id, cluster(party_id)


********************************************************************************
***** 3.9 Table A18
********************************************************************************

reg log_per401_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_middcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per401_100_1 l_actualflows l_unemp l_realgdpgr l_debt l_workcl_left2vote_ma2 l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)



********************************************************************************
********************************************************************************
********************************************************************************
***** 4. Macro-level analysis
********************************************************************************
********************************************************************************
********************************************************************************

*use "C:\Users\Engler\Papers\LeftPartiesVoterPreferencesEconomicPolicy\PartPosAnalyse\replication_Engler_Zohlnhoefer_2018_macro-level_final.dta", clear

xtset ccode year

set scheme sj


********************************************************************************
***** 4.1 Variable description
********************************************************************************

* subsidies                   -> subsidy spending in percentage of GDP
* ectr                        -> OECD ETCR index of product market regulation
* privatis                    -> index of state ownership
* proz_left2                  -> cabinet seat share of left parties (socialists/communists, social-democrats, and Greens cumulated)
* middcl_left2vote_ma2        -> share of working-class voters among all employed left party voters (moving average (t), (t-1) (t-2))
* workcl_left2vote_ma2        -> share of working-class voters among all employed left party voters (moving average (t), (t-1) (t-2))
* routcl_left2vote_ma2        -> share of routine class voters among all employed left party voters (moving average (t), (t-1) (t-2))
* emplcl_left2vote_ma2        -> share of employer class voters among all employed left party voters (moving average (t), (t-1) (t-2))
* actual flows                -> actual flows sub-index of Dreher's (2006) KOF index of globalization
* unemp                       -> unemployment rate
* realgdpgr                   -> GDP growth
* debt                        -> public debt in percentage of GDP
* ud                          -> union density
* proz_left1                  -> cabinet seat share of old left parties (socialist/communist and social-democratic but not Greens cumulated)
* middcl_leftvote_ma2         -> share of middle-class voters among all employed old left party voters (socialists/communists and social-democrats but not Greens) (moving average (t), (t-1) (t-2))
* workcl_leftvote_ma2         -> share of working-class voters among all employed old left party voters (socialists/communists and social-democrats but not Greens) (moving average (t), (t-1) (t-2))
* profintperscl_left2vote_ma2 -> share of new middle-class voters (i.e. sociocultural (semi-)professionals) among all employed left party voters (moving average (t), (t-1) (t-2))
* lowercl_left2vote_ma2       -> sum of the shares of working-class voters and routine service class voters among all employed left party voters (moving average (t), (t-1) (t-2))
* middcl_left2vote_V2_ma2     -> share of working-class voters among all (employed and not employed) left party voters (moving average (t), (t-1) (t-2))
* workcl_left2vote_V2_ma2     -> share of working-class voters among all (employed and not employed) left party voters (moving average (t), (t-1) (t-2))
* middclv_allv_V2_ma2         -> share of middle-class voters among all voters (not only left party voters) (moving average (t), (t-1) (t-2))
* workclv_allv_V2_ma2         -> share of working-class voters among all voters (not only left party voters) (moving average (t), (t-1) (t-2))
* proz_left2_dich             -> Dummy for left parties in government, based on proz_left2 (1 yes) (0 no)
* left2_pm                    -> Dummy for left head of government, coding based on Schmidt (2015) (1 yes) (0 no)
* year                        -> year
* ccode                       -> country code


********************************************************************************
***** 4.2 Table A19
********************************************************************************

generate left2_middcl_ma2=proz_left2*middcl_left2vote_ma2
generate left2_workcl_ma2=proz_left2*workcl_left2vote_ma2

xtpcse d.subsidies L.subsidies L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.3 Table A20
********************************************************************************

generate left1_middcl_ma2=proz_left1*middcl_leftvote_ma2
generate left1_workcl_ma2=proz_left1*workcl_leftvote_ma2

xtpcse d.subsidies L.subsidies L.left1_middcl_ma2 L.middcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left1_middcl_ma2 L.middcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left1_middcl_ma2 L.middcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left1_workcl_ma2 L.workcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left1_workcl_ma2 L.workcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left1_workcl_ma2 L.workcl_leftvote_ma2 L.proz_left1 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.4 Table A21
********************************************************************************

generate left2_profintpers=profintperscl_left2vote_ma2*proz_left2
generate left2_lowercl=lowercl_left2vote_ma2*proz_left2

xtpcse d.subsidies L.subsidies L.left2_profintpers L.profintperscl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_profintpers L.profintperscl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_profintpers L.profintperscl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_lowercl L.lowercl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_lowercl L.lowercl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_lowercl L.lowercl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.5 Table A22
********************************************************************************

generate left2_middcl_V2_ma2=proz_left2*middcl_left2vote_V2_ma2
generate left2_workcl_V2_ma2=proz_left2*workcl_left2vote_V2_ma2

xtpcse d.subsidies L.subsidies L.left2_middcl_V2_ma2 L.middcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_middcl_V2_ma2 L.middcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_middcl_V2_ma2 L.middcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_workcl_V2_ma2 L.workcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_workcl_V2_ma2 L.workcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_workcl_V2_ma2 L.workcl_left2vote_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.6 Table A23
********************************************************************************

generate left2_middclvallv_V2_ma2=proz_left2*middclv_allv_V2_ma2
generate left2_workclvallv_V2_ma2=proz_left2*workclv_allv_V2_ma2

xtpcse d.subsidies L.subsidies L.left2_middclvallv_V2_ma2 L.middclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_middclvallv_V2_ma2 L.middclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_middclvallv_V2_ma2 L.middclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_workclvallv_V2_ma2 L.workclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_workclvallv_V2_ma2 L.workclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_workclvallv_V2_ma2 L.workclv_allv_V2_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.7 Table A24
********************************************************************************

xtpcse d.subsidies L.subsidies L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year<2002, correlation(ar1)


********************************************************************************
***** 4.8 Table A25
********************************************************************************

xtpcse d.subsidies L.subsidies L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode if year>=2004, correlation(ar1)


********************************************************************************
***** 4.9 Table A26
********************************************************************************

generate left2_dich_middcl_ma2=proz_left2_dich*middcl_left2vote_ma2
generate left2_dich_workcl_ma2=proz_left2_dich*workcl_left2vote_ma2

xtpcse d.subsidies L.subsidies L.left2_dich_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_dich_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_dich_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_dich_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_dich_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_dich_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2_dich L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.10 Table A27
********************************************************************************

generate left2_pm_middcl_ma2=left2_pm*middcl_left2vote_ma2
generate left2_pm_workcl_ma2=left2_pm*workcl_left2vote_ma2

xtpcse d.subsidies L.subsidies L.left2_pm_middcl_ma2 L.middcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_pm_middcl_ma2 L.middcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_pm_middcl_ma2 L.middcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.subsidies L.subsidies L.left2_pm_workcl_ma2 L.workcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.left2_pm_workcl_ma2 L.workcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.left2_pm_workcl_ma2 L.workcl_left2vote_ma2 L.left2_pm L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.11 Table A28
********************************************************************************

xtpcse d.subsidies L.subsidies L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.ectr L.ectr L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)

xtpcse d.privatis L.privatis L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)


********************************************************************************
***** 4.12 Figure 1
********************************************************************************

********************************************************************************
***Subsidies / Middle-class
********************************************************************************
xtpcse d.subsidies L.subsidies L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize middcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen middcl_left2vote_ma2a=middcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize middcl_left2vote_ma2a
   gen left2_middcl_left2votea=proz_left2*middcl_left2vote_ma2a
   xtpcse d.subsidies L.proz_left2 L.left2_middcl_left2votea L.subsidies L.middcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop middcl_left2vote_ma2a left2_middcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on Subsidies" "at various Levels of Middle Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Middle Class Vote Share") ///
	legend(off)
graph save middcl_subs, replace
drop poi*

********************************************************************************
***Subsidies / Working-class
********************************************************************************
xtpcse d.subsidies L.subsidies L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize workcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen workcl_left2vote_ma2a=workcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize workcl_left2vote_ma2a
   gen left2_workcl_left2votea=proz_left2*workcl_left2vote_ma2a
   xtpcse d.subsidies L.proz_left2 L.left2_workcl_left2votea L.subsidies L.workcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop workcl_left2vote_ma2a left2_workcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on Subsidies" "at various Levels of Working Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Working Class Vote Share") ///
	legend(off)
graph save workcl_subs, replace
drop poi*

graph combine "middcl_subs" "workcl_subs", iscale(*0.68)
graph save conditional_subsidies, replace


********************************************************************************
***** 4.13 Figure A1
********************************************************************************

sort year country

egen mean_middcl_left2vote_ma2=mean(middcl_left2vote_ma2), by(year)
egen mean_workcl_left2vote_ma2=mean(workcl_left2vote_ma2), by(year)
egen mean_routcl_left2vote_ma2=mean(routcl_left2vote_ma2), by(year)
egen mean_emplcl_left2vote_ma2=mean(emplcl_left2vote_ma2), by(year)

graph twoway (line mean_middcl_left2vote_ma2 year) (line mean_workcl_left2vote_ma2 year) (line mean_routcl_left2vote_ma2 year) (line mean_emplcl_left2vote_ma2 year), ///
yscale(r(0.05 0.65)) ylabel(0.1(0.1)0.6, labsize(small)) ymtick(0.05(0.05)0.65) ///
xlabel(1980(5)2012, labsize(small)) xmtick(1980(1)2012) ///
legend(label(1 "Middle Class Voters") label(2 "Working Class Voters") label(3 "Routine Class Voters") label(4 "Employer Class Voters") size(small)) ///
xtitle(" ") ///
ytitle("Share of all Employed Left Party Voters" " ", size(small)) 


********************************************************************************
***** 4.14 Figure A3
********************************************************************************

xtset ccode year


********************************************************************************
***Regulation / Middle-class
********************************************************************************
xtpcse d.ectr L.ectr L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize middcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen middcl_left2vote_ma2a=middcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize middcl_left2vote_ma2a
   gen left2_middcl_left2votea=proz_left2*middcl_left2vote_ma2a
   xtpcse d.ectr L.proz_left2 L.left2_middcl_left2votea L.ectr L.middcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop middcl_left2vote_ma2a left2_middcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on Product Market Regulation" "at various Levels of Middle Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Middle Class Vote Share") ///
	legend(off)
graph save middcl_ectr, replace
drop poi*

********************************************************************************
***Regulation / Working-class
********************************************************************************
xtpcse d.ectr L.ectr L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize workcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen workcl_left2vote_ma2a=workcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize workcl_left2vote_ma2a
   gen left2_workcl_left2votea=proz_left2*workcl_left2vote_ma2a
   xtpcse d.ectr L.proz_left2 L.left2_workcl_left2votea L.ectr L.workcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop workcl_left2vote_ma2a left2_workcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on Product Market Regulation" "at various Levels of Working Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Working Class Vote Share") ///
	legend(off)
graph save workcl_ectr, replace
drop poi*

********************************************************************************
***Privatization / Middle-class
********************************************************************************
xtpcse d.privatis L.privatis L.left2_middcl_ma2 L.middcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize middcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen middcl_left2vote_ma2a=middcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize middcl_left2vote_ma2a
   gen left2_middcl_left2votea=proz_left2*middcl_left2vote_ma2a
   xtpcse d.privatis L.proz_left2 L.left2_middcl_left2votea L.privatis L.middcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop middcl_left2vote_ma2a left2_middcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on State Ownership" "at various Levels of Middle Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Middle Class Vote Share") ///
	legend(off)
graph save middcl_priv, replace
drop poi*

********************************************************************************
***Privatization / Working-class
********************************************************************************
xtpcse d.privatis L.privatis L.left2_workcl_ma2 L.workcl_left2vote_ma2 L.proz_left2 L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
quietly summarize workcl_left2vote_ma2, detail 
local min=r(min)
local max=r(max)
local mean=r(mean)
local cen25=r(p25)
local cen50=r(p50)
local cen75=r(p75)
local numparams=11			
local inc=(`max'-`min')/(`numparams'-1)
local iter=0
matrix foo2 = 0,0,0,0
local order=1
*  
while `iter'<`numparams' { 
   gen workcl_left2vote_ma2a=workcl_left2vote_ma2 -`min'-(`inc'*`iter')  
   summarize workcl_left2vote_ma2a
   gen left2_workcl_left2votea=proz_left2*workcl_left2vote_ma2a
   xtpcse d.privatis L.proz_left2 L.left2_workcl_left2votea L.privatis L.workcl_left2vote_ma2a L.actualflows L.unemp L.realgdpgr L.debt L.ud i.year i.ccode, correlation(ar1)
   matrix betas=e(b)                
   scalar x1coef=betas[1,`order']
   matrix ses=e(V)
   scalar x1se=sqrt(ses[`order',`order'])
   local obs=e(N)                     
   scalar ci95=invttail(`obs', 0.025) 
   local xval = `min'+(`inc'*`iter')
   matrix foo = x1coef-ci95*x1se, x1coef, x1coef+ci95*x1se,`xval'
   matrix foo2 = foo2 \ foo
   drop workcl_left2vote_ma2a left2_workcl_left2votea
   local iter=`iter'+1
   }
matrix points=foo2[2..(`numparams'+1),1..4]
svmat points
*   
twoway (connected points1 points2 points3 points4, ///
		clcolor(black black black) ///
		msymbol(i i i) ///
		lpattern(dash solid dash)), ///
	title("Effect of Left Parties on State Ownership" "at various Levels of Working Class Vote Share" " ", size(medium)) ///
	ytitle("Marginal Effect of Left Parties" " ") ///
	yline(0, lwidth(medthin)) ///
	xtitle(" " "Working Class Vote Share") ///
	legend(off)
graph save workcl_priv, replace
drop poi*

graph combine "middcl_ectr" "workcl_ectr" "middcl_priv" "workcl_priv", cols(2) iscale(*0.75)
graph save conditional_regulation_ownership, replace




********************************************************************************
********************************************************************************
********************************************************************************
***** 5. Endogeneity tests
********************************************************************************
********************************************************************************
********************************************************************************

*use "C:\Users\Engler\Papers\LeftPartiesVoterPreferencesEconomicPolicy\PartPosAnalyse\replication_Engler_Zohlnhoefer_2018_party-level_final.dta", clear

xtset party_id election_number

********************************************************************************
***** 5.2 Table A1
********************************************************************************

* middcl_left2vote -> share of middle-class voters among all employed left party voters (in the election year)
* workcl_left2vote -> share of working-class voters among all employed left party voters (in the election year)
* l_per402_100     -> Comparative Manifesto Project (Volkens et al. 2017) item "per402: incentives: positive", original data (proportion instead of absolute percentages)  (1 election lag)
* l_per403_100     -> Comparative Manifesto Project (Volkens et al. 2017) item "per403: market regulation", original data (proportion instead of absolute percentages)  (1 election lag)
* l_per413_100     -> Comparative Manifesto Project (Volkens et al. 2017) item "per413: nationalisation", original data (proportion instead of absolute percentages)  (1 election lag)
* For all other variables, see section 3.1


********************************************************************************
***** 5.2 Table A1
********************************************************************************

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt middcl_left2vote l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per402_100_1 l_actualflows l_unemp l_realgdpgr l_debt workcl_left2vote l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt middcl_left2vote l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per403_100_1 l_actualflows l_unemp l_realgdpgr l_debt workcl_left2vote l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt middcl_left2vote l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg log_per413_100_1 l_actualflows l_unemp l_realgdpgr l_debt workcl_left2vote l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)


********************************************************************************
***** 5.3 Table A2
********************************************************************************

reg middcl_left2vote per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote per402_100 l_actualflows l_unemp l_realgdpgr l_debt l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg middcl_left2vote per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote per403_100 l_actualflows l_unemp l_realgdpgr l_debt l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg middcl_left2vote per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote per413_100 l_actualflows l_unemp l_realgdpgr l_debt l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)


********************************************************************************
***** 5.4 Table A3
********************************************************************************

gen incentives_mean=(per402_100+l_per402_100)/2
gen regulation_mean=(per403_100+l_per403_100)/2
gen nationalisation_mean=(per413_100+l_per413_100)/2


reg middcl_left2vote incentives_mean l_actualflows l_unemp l_realgdpgr l_debt l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote incentives_mean l_actualflows l_unemp l_realgdpgr l_debt l_subsidies l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg middcl_left2vote regulation_mean l_actualflows l_unemp l_realgdpgr l_debt l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote regulation_mean l_actualflows l_unemp l_realgdpgr l_debt l_ectr l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg middcl_left2vote nationalisation_mean l_actualflows l_unemp l_realgdpgr l_debt l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)

reg workcl_left2vote nationalisation_mean l_actualflows l_unemp l_realgdpgr l_debt l_privatis l_ud dummy_80 dummy_90 i.ccode, cluster(ccode)



********************************************************************************
********************************************************************************
***** End of Do-File
********************************************************************************
********************************************************************************
